BubbleRootProps

Struct BubbleRootProps 

pub struct BubbleRootProps {}
Props for the BubbleRoot component.

Leptos component mounted at ?mount=bubble. Renders the borderless circular webcam surface with overlaid controls.

Implementations

Source

impl BubbleRootProps

pub fn builder() -> BubbleRootPropsBuilder<()>

Create a builder for building BubbleRootProps. On the builder, call to set the values of the fields. Finally, call .build() to create the instance of BubbleRootProps.