add_zoom_at_cursor

Function add_zoom_at_cursor 

pub fn add_zoom_at_cursor(
    project: RwSignal<Option<EditProject>>,
    history: StoredValue<Option<History>>,
    at: u64,
)
Like add_zoom_default but punches in on the cursor at the playhead — the manual “zoom into the cursor” action. The target is the cursor’s position at at from the project’s captured track ([EditProject::zoom_cursor_target]), falling back to centre when no track was captured (so it degrades to the same result as add_zoom_default).