pub fn install_editor_preview(
_project: Option<RwSignal<Option<EditProject>>>,
_status: RwSignal<EditorStatus>,
)Expand description
Native stub — the editor preview runs only in the wasm webview.
pub fn install_editor_preview(
_project: Option<RwSignal<Option<EditProject>>>,
_status: RwSignal<EditorStatus>,
)Native stub — the editor preview runs only in the wasm webview.