fn default_toolbar(loaded: bool) -> Vec<ToolbarActionView>Expand description
The editor toolbar action set (matches the reference design). When no clip is loaded every action is disabled.
fn default_toolbar(loaded: bool) -> Vec<ToolbarActionView>The editor toolbar action set (matches the reference design). When no clip is loaded every action is disabled.