pub async fn request_screen_recording_permission()Expand description
Trigger the platform Screen Recording permission flow. On macOS this is the call that creates the row in System Settings after a TCC reset.
pub async fn request_screen_recording_permission()Trigger the platform Screen Recording permission flow. On macOS this is the call that creates the row in System Settings after a TCC reset.