fn suggested_bundle_ids(apps: &[AudioAppView]) -> Vec<String>Expand description
Walk the running-app list and pull out bundle ids whose prefix
is in SUGGESTED_BUNDLE_PREFIXES.
fn suggested_bundle_ids(apps: &[AudioAppView]) -> Vec<String>Walk the running-app list and pull out bundle ids whose prefix
is in SUGGESTED_BUNDLE_PREFIXES.